Learn R Programming

orloca (version 5.6)

andalusia: Cities of Andalusia

Description

The 'andalusia' data frame has 12 rows and 4 columns, which are the geographical position of the main capital cities of andalusia.

Arguments

Format

name: The name of the city or relative position label.

x: The x coordinate of points.

y: The y coordinate of points.

city: If yes the point is a city in other case is a limit.

Usage

data('andalusia')

See Also

See also orloca-package.