as.matrix.loca.p: as.matrix.loca.p
S3 method to convert from loca.p to matrix
Description
Conversions between loca.p class and some others classes
Usage
# S3 method for loca.p
as.matrix(x, rownames.force = NA, ...)
Value
It returns a new object of the new class.
Arguments
x
is the object to convert to the new class object.
rownames.force
If True the rownames is setted
...
Other arguments, unused.
Details
Methods to convert from and to loca.p class.
NA's values are not allowed in any of the arguments.
The matrix or data.frame to convert into loca.p must have at least two columns.
The first column will be consider as the x coordinates, the second as the y coordinates, and the third (if given) as the values of weights w.