Learn R Programming

orloca (version 5.6)

distsuml2: distsuml2 and distsuml2gra at orloca package

Description

distsum and distsumgra functions for the Euclidean norm (\(l_2\)). Mainly for internal use.

Usage

distsuml2(o, x = 0, y = 0)

Value

distsuml2 returns the objective function of the min-sum location problem, \(\sum_{a_i \in o} w_i d(a_i, (x,y))\), where \(d(a_i, (x,y))\) gives the euclidean distances between \(a_i\) and the point \((x,y)\). distsumgra returns the gradient vector of the function distsum.

Arguments

o

An object of loca.p class.

x

The x coordinate of the point to be evaluated.

y

The y coordinate of the point to be evaluated.

Details

If \((x,y)\) is a demand point partial=T means ignore such point to compute the gradient. This option is mainly for internal use.

See Also

See also orloca-package, distsum, distsumgra and distsummin.