The algorithms Weiszfeld and gradient include and optimality test for demand points.
The Weiszfeld version of the algorithm also implements slow convergence test and accelerator procedure.
If \(p < 1\) thus \(l_p\) is not a norm, so, only \(p \ge 1\) are valid values.
Since \(l_2\) norm is the Euclidean norm, when \(p=2\) distsumlpmin are equal to distsummin.
But the computations involved are greater for the first form.
max.iter for SANN algorithm is the number of evaluation of objective function, so this method usually requires large values of max.iter to reach optimal value
The function zsummin is deprecated and will be removed from new versions of the package.