Package: orloca
Type: Package
Version: 5.6
Date: 2024-01-31
License: GPL (>= 3)
The min-sum location problem search for a point such that the weighted sum of the distances to the demand points are minimized. See "The Fermat-Weber location problem revisited" by Brimberg, Mathematical Programming, 1, pg. 71-76, 1995, tools:::Rd_expr_doi("10.1007/BF01592245").
General global optimization algorithms are used to solve the problem, along with the adhoc Weiszfeld method, see "Sur le point pour lequel la Somme des distances de n points donnes est minimum", by E. Weiszfeld, Tohoku Mathematical Journal, First Series, 43, pg. 355-386, 1937 or "On the point for which the sum of the distances to n given points is minimum", by E. Weiszfeld and F. Plastria, Annals of Operations Research, 167, pg. 7-41, 2009, tools:::Rd_expr_doi("10.1007/s10479-008-0352-z").
The package provides a class loca.p that represents a location problem with a finite set of demand points on the plane.
Also, it is possible to plot the points and the objective function.
Such objective function is the total weighted distances travelled by all the customers to the service.
Non-planar location problems could be handle in future versions of the package.
For a demo, load the package with the instruction library(orloca), and run the demo executing the instruction demo(orloca).
The package is ready for internationalization. The author kindly ask for translated version of the .mo file to include in the package.