Learn R Programming

orloca (version 5.6)

persp.loca.p: Plots of the min-sum objective function

Description

persp provides a graphical representations of objetive function of the min-sum problem, which is the total weighte distance to the demand points (distsum).

Usage

# S3 method for loca.p
persp(
  x,
  lp = numeric(0),
  xmin = min(x@x),
  xmax = max(x@x),
  ymin = min(x@y),
  ymax = max(x@y),
  n = 10,
  ticktype = "detailed",
  ...
)

Value

A plot a 3D plot or min-sum function.

Arguments

x

The loca.p object to compute the objective.

lp

If given, then \(l_p\) norm will be used instead of the Euclidean norm.

xmin

The minimum value for x axis.

xmax

The maximum value for x axis.

ymin

The minimum value for y axis.

ymax

The maximum value for y axis.

n

The number of divisions for grid.

ticktype

parameter to pass to low level function persp

...

Other options.

Details

If \(p<1\) then \(l_p\) is not a norm, so only \(p>=1\) are valid values.

See Also

See also orloca-package, plot.loca.p and loca.p.

Examples

Run this code
# A new unweighted loca.p object
loca <- loca.p(x = c(-1, 1, 1, -1), y = c(-1, -1, 1, 1))

# The 3D graphics
persp(loca)

Run the code above in your browser using DataLab