powered by
The 'andalusia' data frame has 12 rows and 4 columns, which are the geographical position of the main capital cities of andalusia.
name: The name of the city or relative position label.
name
x: The x coordinate of points.
x
y: The y coordinate of points.
y
city: If yes the point is a city in other case is a limit.
city
data('andalusia')
See also orloca-package.
orloca-package