as.loca.p.data.frame: as.loca.p.data.frame
S3 method to convert from data.frame to loca.p
Description
Conversions between loca.p class and some others classes
Usage
as.loca.p.data.frame(x, ...)
Value
It returns a new object of the new class.
Arguments
x
is the object to convert to the new class object.
...
Other arguments, unused.
Details
Methods to convert from and to loca.p class.
NA's values are not allowed in any of the arguments.
The matrix or data.frame to convert into loca.p must have at least two columns.
The first column will be consider as the x coordinates, the second as the y coordinates, and the third (if given) as the values of weights w.