distsum and distsumgra functions for the Euclidean norm (\(l_2\)). Mainly for internal use.
distsuml2(o, x = 0, y = 0)distsuml2 returns the objective function of the min-sum location problem, \(\sum_{a_i \in o} w_i d(a_i, (x,y))\), where \(d(a_i, (x,y))\) gives the euclidean distances between \(a_i\) and the point \((x,y)\). distsumgra returns the gradient vector of the function distsum.
An object of loca.p class.
The x coordinate of the point to be evaluated.
The y coordinate of the point to be evaluated.
If \((x,y)\) is a demand point partial=T means ignore such point to compute the gradient. This option is mainly for internal use.
See also orloca-package, distsum, distsumgra and distsummin.